<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="aboutdialog.ui" line="14"/>
        <source>About Trafikanten for Maemo</source>
        <translation>Om Trafikanten for Maemo</translation>
    </message>
    <message>
        <location filename="aboutdialog.ui" line="35"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;Trafikanten for Maemo is developed by Svenn-Arne Dragly and is released under the GNU GPLv3 license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;Trafikanten for Maemo gives you information about the public transport system in Oslo and Akershus. It includes information about bus, metro, tram and boat, as well as train for all county&apos;s in Eastern Norway. The system knows where the vehicle is, and calculates the time of departure in real time.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;&amp;quot;Ca&amp;quot; before the expected arrival time indicates that this travel lacks real time information. The travel might be delayed or arrive at a later time.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;&lt;br /&gt;Real time data for train is delivered by Jernbaneverket.&lt;br /&gt;&lt;br /&gt;For more information about this application, visit &lt;/span&gt;&lt;a href=&quot;http://www.dragly.org/projects/trafikanten-maemo/&quot;&gt;&lt;span style=&quot; font-size:14pt; text-decoration: underline; color:#0000ff;&quot;&gt;dragly.org/projects/trafikanten-maemo&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;&lt;br /&gt;For more information about Trafikanten and applications for other platforms, go to &lt;/span&gt;&lt;a href=&quot;http://www.trafikanten.no/&quot;&gt;&lt;span style=&quot; font-size:14pt; text-decoration: underline; color:#0000ff;&quot;&gt;trafikanten.no&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;. For Trafikanten&apos;s official travel planner, go to &lt;/span&gt;&lt;a href=&quot;http://m.trafikanten.no/&quot;&gt;&lt;span style=&quot; font-size:14pt; text-decoration: underline; color:#0000ff;&quot;&gt;m.trafikanten.no&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;This program is free software: you can redistribute it and/or modify&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;it under the terms of the GNU General Public License as published by&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;the Free Software Foundation, either version 3 of the License, or&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;(at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;This program is distributed in the hope that it will be useful,&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;but WITHOUT ANY WARRANTY; without even the implied warranty of&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:14pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;You should have received a copy of the GNU General Public License&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;along with this program.  If not, see &amp;lt;http://www.gnu.org/licenses/&amp;gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DepartureListDelegate</name>
    <message>
        <location filename="departureswindow.cpp" line="170"/>
        <source>now</source>
        <translation>nå</translation>
    </message>
    <message>
        <location filename="departureswindow.cpp" line="172"/>
        <source> min</source>
        <translation> min</translation>
    </message>
</context>
<context>
    <name>DeparturesWindow</name>
    <message>
        <location filename="departureswindow.ui" line="14"/>
        <source>Departures</source>
        <translation>Avganger</translation>
    </message>
    <message>
        <location filename="departureswindow.ui" line="36"/>
        <source>Departures from</source>
        <translation>Avganger fra</translation>
    </message>
    <message>
        <location filename="departureswindow.ui" line="51"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="departureswindow.ui" line="113"/>
        <source>Menu</source>
        <translation>Meny</translation>
    </message>
    <message>
        <location filename="departureswindow.ui" line="122"/>
        <source>Route from here</source>
        <translation>Rute fra denne holdeplassen</translation>
    </message>
    <message>
        <location filename="departureswindow.ui" line="127"/>
        <source>Route to here</source>
        <translation>Rute til denne holdeplassen</translation>
    </message>
</context>
<context>
    <name>RouteSearchWindow</name>
    <message>
        <source>Route Search</source>
        <translation type="obsolete">Rutesøk</translation>
    </message>
    <message>
        <source>From:</source>
        <translation type="obsolete">Fra:</translation>
    </message>
    <message>
        <source>Search for place</source>
        <translation type="obsolete">Søk etter sted</translation>
    </message>
    <message>
        <source>Click to select station</source>
        <translation type="obsolete">Klikk for å velge stasjon</translation>
    </message>
    <message>
        <source>To:</source>
        <translation type="obsolete">Til:</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="obsolete">Søk</translation>
    </message>
    <message>
        <source>Routing info is not yet available</source>
        <translation type="obsolete">Ruteinfo er ikke tilgjengelig ennå</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="searchdialog.ui" line="14"/>
        <location filename="searchdialog.ui" line="46"/>
        <location filename="searchdialog.cpp" line="38"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <location filename="searchdialog.cpp" line="44"/>
        <source>Places Nearby</source>
        <translation>Steder i nærheten</translation>
    </message>
</context>
<context>
    <name>SearchWindow</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Søk</translation>
    </message>
    <message>
        <source>Search Nearby Places</source>
        <translation type="obsolete">Søk i nærheten</translation>
    </message>
</context>
<context>
    <name>TrafikantenWindow</name>
    <message>
        <location filename="trafikantenwindow.ui" line="14"/>
        <source>Trafikanten</source>
        <translation>Trafikanten</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="37"/>
        <source>Trafikanten for Maemo gives you real time information about the public transport system in Oslo and other areas of Norway.</source>
        <translation>Trafikanten for Maemo gir deg sanntidsinfo for kollektivtransporten i Oslo og omegn.</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="86"/>
        <source>Recent</source>
        <translation>Nylige søk</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="114"/>
        <source>Find travel</source>
        <oldsource>Find route</oldsource>
        <translation>Finn rute</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="142"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="170"/>
        <source>Nearby</source>
        <translation>I nærheten</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="189"/>
        <source>Menu</source>
        <translation>Meny</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="197"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.ui" line="202"/>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.cpp" line="214"/>
        <source>Timed out</source>
        <translation>Tidsavbrudd</translation>
    </message>
    <message>
        <location filename="trafikantenwindow.cpp" line="215"/>
        <source>We are terribly sorry, but we&apos;re unable to locate your position at the current time. Please try again.</source>
        <translation>Vi beklager, men det var dessverre ikke mulig å lokalisere din posisjon for øyeblikket. Vennligst prøv igjen senere.</translation>
    </message>
</context>
<context>
    <name>TravelInfoDialog</name>
    <message>
        <location filename="travelinfodialog.ui" line="14"/>
        <source>Travel Info</source>
        <translation>Reiseinformasjon</translation>
    </message>
</context>
<context>
    <name>TravelListDelegate</name>
    <message numerus="yes">
        <location filename="travelsearchwindow.cpp" line="229"/>
        <source>%n switche(s)</source>
        <translation>
            <numerusform>%n bytte</numerusform>
            <numerusform>% bytter</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="travelsearchwindow.cpp" line="238"/>
        <source>%n min</source>
        <translation>
            <numerusform>% min</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TravelSearchWindow</name>
    <message>
        <location filename="travelsearchwindow.ui" line="14"/>
        <source>Travel Search</source>
        <translation>Reisesøk</translation>
    </message>
    <message>
        <location filename="travelsearchwindow.ui" line="38"/>
        <source>From:</source>
        <translation>Fra:</translation>
    </message>
    <message>
        <location filename="travelsearchwindow.ui" line="45"/>
        <source>Select Departure</source>
        <translation>Velg avreise</translation>
    </message>
    <message>
        <location filename="travelsearchwindow.ui" line="52"/>
        <source>To:</source>
        <translation>Til:</translation>
    </message>
    <message>
        <location filename="travelsearchwindow.ui" line="59"/>
        <source>Select Destination</source>
        <translation>Velg destinasjon</translation>
    </message>
    <message>
        <location filename="travelsearchwindow.ui" line="69"/>
        <source>Departure:</source>
        <translation>Tidspunkt:</translation>
    </message>
    <message>
        <location filename="travelsearchwindow.ui" line="78"/>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>TravelStageListDelegate</name>
    <message>
        <location filename="travelinfodialog.cpp" line="95"/>
        <source>Walking</source>
        <translation>Gangvei</translation>
    </message>
    <message numerus="yes">
        <location filename="travelinfodialog.cpp" line="108"/>
        <location filename="travelinfodialog.cpp" line="123"/>
        <source>%n min</source>
        <translation>
            <numerusform>%n min</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
</TS>
